@@ -1,4 +1,4 @@
-from random import randint
+from random import randint, choice
 from mongoengine import *
 
 from generators import *
@@ -32,14 +32,29 @@ class MongoFuel():
         mongo_fuel = cls(document)
         return mongo_fuel._create(persists=persists, **args)
 
+    @classmethod
+    def create_many(cls, document, instances=5, persists=True):
+        documents = []
+        mongo_fuel = MongoFuel(document)
+
+        for i in range(0, instances):
+            documents.append(mongo_fuel._create(persists=persists))
+
+        return documents
+
     def _create(self, persists=True, **attrs):
         '''Returns an instance of MongoFuel's instance document'''
 
         for field_name, field in self.fields.items():
-            if isinstance(field, ObjectIdField) or field_name in attrs:
+            if isinstance(field, ObjectIdField) or field_name in attrs or not field.required:
                 continue
 
-            if isinstance(field, ListField):
+            if field.default is not None and \
+                    not getattr(field.default, '__call__', None):
+                value = field.default
+            elif field.choices:
+                value = choice(field.choices)
+            elif isinstance(field, ListField):
                 value = []
                 list_field = field.field
                 for i in range(0, randint(1, 10)):
